/**
 * @file
 * JavaScript API for the Content moderation edit notify module.
 *
 * May only be loaded for authenticated users on node edit form for moderated
 * content types.
 */

(($, Drupal, drupalSettings) => {
  const currentUserID = parseInt(drupalSettings.user.uid, 10);
  const { node } = drupalSettings.content_moderation_edit_notify[currentUserID];
  const { interval } = drupalSettings.content_moderation_edit_notify;
  const notifiedList = [];

  /**
   * @namespace
   */
  Drupal.content_moderation_edit_notify = {
    /**
     * Fetch information on this node revision.
     *
     * @param {array} node
     *   A node array with number nid and vid.
     */
    checkLastRevision() {
      if (node.hasOwnProperty("nid") && node.hasOwnProperty("vid")) {
        $.ajax({
          url: Drupal.url(
            `content_moderation_edit_notify/${node.nid}/${node.vid}/check`
          ),
          type: "POST",
          dataType: "json",
          success(response) {
            if (
              response.hasOwnProperty("message") &&
              response.hasOwnProperty("last_vid")
            ) {
              // Check if we already set a message for this revision.
              if (!notifiedList[response.last_vid]) {
                notifiedList[response.last_vid] = true;
                $("form.node-form").prepend(response.message);
                $("form.node-form .form-actions").prepend(response.message);
              }
            }
          }
        });
      }
    }
  };

  /**
   * Registers behaviors related to the ajax request.
   */
  Drupal.behaviors.contentModerationEditNotify = {
    attach(context) {
      $(context)
        .find(".node-form")
        .once("editCheck")
        .each(() => {
          setInterval(() => {
            Drupal.content_moderation_edit_notify.checkLastRevision();
          }, interval);
        });
    }
  };
})(jQuery, Drupal, drupalSettings);
