<?php

namespace Drupal\content_moderation_edit_notify\Hook;

use Drupal\content_moderation\ModerationInformationInterface;
use Psr\Log\LoggerInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\node\NodeInterface;

/**
 * Implements form_node_form_alter().
 */
class NodeFormAlter {

  /**
   * The moderation information service.
   *
   * @var \Drupal\content_moderation\ModerationInformationInterface
   */
  protected $moderationInfo;

  /**
   * The current user service.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * A logger instance.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * The notify interval.
   *
   * @var int
   */
  private $notifyInterval;

  /**
   * Constructs a new instance.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\content_moderation\ModerationInformationInterface $moderation_info
   *   The moderation information service.
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   The current user.
   */
  public function __construct(ConfigFactoryInterface $config_factory, LoggerInterface $logger, ModerationInformationInterface $moderation_info, AccountInterface $current_user) {
    $config = $config_factory->get('content_moderation_edit_notify.settings');
    $this->notifyInterval = $config->get('interval');
    $this->logger = $logger;
    $this->moderationInfo = $moderation_info;
    $this->currentUser = $current_user;
  }

  /**
   * Alter the node form.
   *
   * @param array $form
   *   Nested array of form elements that comprise the form.
   * @param \Drupal\node\NodeInterface $node
   *   The node related by this form.
   */
  public function alter(array &$form, NodeInterface $node) {

    // Check if we are on a moderated content.
    if ($this->moderationInfo->isModeratedEntity($node)) {
      // When coming back from preview, getRevisionId is empty.
      $vid = $node->getRevisionId();
      if ($vid == NULL) {
        $vid = $node->getLoadedRevisionId();
      }
      // Log in case of error.
      if ($vid == NULL) {
        $this->logger->warning('Missing version for node: @nid.', ['@nid' => $node->id()]);
      }
      else {
        // Add our scripts for ajax request on revision based on current
        // version.
        $form['#attached']['library'][] = 'content_moderation_edit_notify/content-moderation-edit-notify';
        $uid = $this->currentUser->id();
        $form['#attached']['drupalSettings']['content_moderation_edit_notify'] = [
          'interval' => $this->notifyInterval * 1000,
          $uid => [
            'node' => [
              'nid' => $node->id(),
              'vid' => $vid,
            ],
          ],
        ];
      }
    }
  }

}
